@@ -307,6 +307,10 @@ class DynamicSetting(object):
 
     def download(self):
 
+        if self.download_in_progress():
+            if self.verbose:
+                print(f'{self.slug} - Download already in progress')
+
         try:
             if self.verbose:
                 print(f'{self.slug} - Downloading...')
